==> vlc_3.0.1.orig.tar.xz: vlc-3.0.1/modules/demux/dash/mpd/DASHSegment.h <==
/*
 * Segment.h
 *****************************************************************************
 * Copyright (C) 2010 - 2011 Klagenfurt University
 *
 * Created on: Aug 10, 2010
 * Authors: Christopher Mueller <christopher.mueller@itec.uni-klu.ac.at>
 *          Christian Timmerer  <christian.timmerer@itec.uni-klu.ac.at>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef DASHSEGMENT_H_
#define DASHSEGMENT_H_

#include "../adaptive/playlist/Segment.h"

namespace dash
{
    namespace mpd
    {
        using namespace adaptive::playlist;
        using namespace adaptive::http;

        class DashIndexSegment : public IndexSegment
        {
            public:
                DashIndexSegment( ICanonicalUrl *parent );

            protected:
                virtual void onChunkDownload(block_t **, SegmentChunk *, BaseRepresentation *); //reimpl
        };

    }
}

#endif /* DASHSEGMENT_H_ */

==> vlc_3.0.16.orig.tar.xz: vlc-3.0.16/modules/demux/dash/mpd/DASHSegment.h <==
/*
 * Segment.h
 *****************************************************************************
 * Copyright (C) 2010 - 2011 Klagenfurt University
 *
 * Created on: Aug 10, 2010
 * Authors: Christopher Mueller <christopher.mueller@itec.uni-klu.ac.at>
 *          Christian Timmerer  <christian.timmerer@itec.uni-klu.ac.at>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef DASHSEGMENT_H_
#define DASHSEGMENT_H_

#include "../../adaptive/playlist/Segment.h"
#include "../../adaptive/playlist/SegmentChunk.hpp"

namespace dash
{
    namespace mpd
    {
        using namespace adaptive::playlist;
        using namespace adaptive::http;

        class DashIndexChunk : public SegmentChunk
        {
            public:
                DashIndexChunk(AbstractChunkSource *, BaseRepresentation *);
                ~DashIndexChunk();
                virtual void onDownload(block_t **); /* reimpl */
        };

        class DashIndexSegment : public IndexSegment
        {
            public:
                DashIndexSegment( ICanonicalUrl *parent );
                ~DashIndexSegment();
                virtual SegmentChunk* createChunk(AbstractChunkSource *, BaseRepresentation *); /* reimpl */
        };

    }
}

#endif /* DASHSEGMENT_H_ */
